<?php
/**
 * Page-description: This php file is the front-end for the infusion administrator. It contains code for creating, editing and deleting Recipe Categories.
 * It also contains code for selecting wich groups have access to the different parts of the system (read, write, moderator)
 * @package infusion
 * @tables dbprefix_recipes_categories, dbprefix_recipes_recipe, dbprefix_recipes_settings
 */

/*---------------------------------------------------+
| PHP-Fusion 6 Content Management System 			 |
+----------------------------------------------------+
| Copyright  2002 - 2005 Nick Jones				 |
| http://www.php-fusion.co.uk/ 						 |
+----------------------------------------------------+
| Released under the terms & conditions of v2 of the |
| GNU General Public License. For details refer to   |
| the included gpl.txt file or visit http://gnu.org  |
+----------------------------------------------------+
| Infusion made by XtraLars, Bigwimp, johanf		 |
| ...as a school project and whatnot				 |
+----------------------------------------------------*/

require_once "../../maincore.php";
require_once BASEDIR."subheader.php";
require_once ADMIN."navigation.php";
if (!checkRights("IP")) { header("Location:../../index.php"); exit; }
if (file_exists(INFUSIONS."recipe_infusion/locale/".$settings['locale'].".php")) {
	include INFUSIONS."recipe_infusion/locale/".$settings['locale'].".php";
} else {
	include INFUSIONS."recipe_infusion/locale/English.php";
}
// FUNCTIONS
/**
* Prints a list/menu containing the registered user groups
* @name printGroupSelects
* @param integer [$selected] Wich group should be selected
* @param boolean [$enablePublic] The recipe the image should be used with.
* @param string [$itemName] The name of the list/menu in the form.
* @return boolean If the user should be able to edit / delete the recipe, it returns true
* @author XtraLars <xtralars@baluba.org>
*/
function printGroupSelects($selected, $enablePublic, $itemName) {
	// Code from forum-administration...
	$post_groups = getusergroups(); 
	$opts = "";
	echo "<select name=\"".$itemName."\" class=\"textbox\" style=\"width:200px\">";
	while(list($key, $user_group) = each($post_groups)){
		if ($user_group['0'] != "0" || $enablePublic) {
			echo "<!-- selected = ".$selected.", user_group = ".$user_group['0']." -->";
			$sel = ($selected == $user_group['0'] ? " selected" : "");
			$opts .= "<option value='".$user_group['0']."'".$sel.">".$user_group['1']."</option>\n";
		}
		//}
	}
	echo $opts;
	echo "</select>";
} 
/**
* Prints a table containing all the registered categories, and the number of registered recioes in each category
* @name printCategoryList
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @global array $locale Array from language-file (locale-file)
* @tables dbprefix_recipes_categories, dbprefix_recipes_recipe
* @author XtraLars <xtralars@baluba.org>
*/
function printCategoryList() {
	global $db_prefix, $locale;
	opentable($locale['REC200']);
	$sql = "SELECT cat.cat_id, cat.cat_name, COALESCE(count(rec.rec_id),0) as recipes"
		  ." FROM ".$db_prefix."recipes_categories cat LEFT OUTER JOIN ".$db_prefix."recipes_recipe rec ON cat.cat_id = rec.cat_id"
		  ." GROUP BY cat.cat_id, cat.cat_name ORDER BY cat.cat_name";
	$result = dbquery($sql);
	$rows = dbrows($result);
	if ($rows != 0) {
		echo "<table width=\"100%\">";
		echo "<tr>";
		echo "<td><strong>".$locale['REC203']."</strong></td>";
		echo "<td align=\"center\"><strong>".$locale['REC202']."</strong></td>";		
		echo "<td align=\"right\"><strong>".$locale['REC014']."</strong></td>";
		echo "</tr>";
		while ($data = dbarray($result)) {
			echo "<tr>";
			echo "<td><a href=\"recipes.php?cat_id=".$data['cat_id']."\">".$data['cat_name']."</a></td>";
			echo "<td align=\"center\">".$data['recipes']."</td>";			
			echo "<td align=\"right\">"
				."<a href=\"?action=edit&amp;cid=".$data['cat_id']."\">".$locale['REC010']."</a> - ";
			if ($data['recipes'] == "0"){
				echo "<a href=\"?action=delete&amp;cid=".$data['cat_id']."\">".$locale['REC012']."</a>";
			} else {
				echo $locale['REC906'];
			}
			echo "</td>";
			echo "</tr>";
		}
		echo "</table>";
	}else {
		echo "<br /><center>".$locale['REC900']."</center><br />";	
	}
	closetable();
	tablebreak();
}
/**
* Prints the form for editing the Infusion Settings (access rights)
* @name printRecipeAdministrationForm
* @global array $recipe_settings Array containing the Infusion Settings.
* @global array $locale Array from language-file (locale-file)
* @author XtraLars <xtralars@baluba.org>
*/
function printRecipeAdministrationForm() {
	global $locale, $recipe_settings;
	$read = $recipe_settings['readaccess'];
	$write = $recipe_settings['usergroup'];
	$moderator = $recipe_settings['moderatorgroup'];
	opentable($locale['REC060']);
		//$selected = "101"; // ### REMOVE THIS LATER - get 
		echo "<form action=\"recipe_admin.php\" method=\"post\">";
		echo "<center><table width=\"500\">";
		echo " <tr><td align=\"right\" width=\"35%\">".$locale['REC061'].": </td><td>";
			printGroupSelects($read, true, "lst_ReadAccess");
		echo "</td></tr>";
		echo " <tr><td align=\"right\">".$locale['REC062'].": </td><td>";
			printGroupSelects($write, false, "lst_WriteAccess");
		echo "</td></tr>";
		echo " <tr><td align=\"right\">".$locale['REC063'].": </td><td>";
			printGroupSelects($moderator, false, "lst_Moderator");
		echo "</td></tr>";

		echo "<tr>"
			." <td colspan=\"2\" align=\"center\">"
			."<input type=\"submit\" name=\"adminSave\" value=\"".$locale['REC013']."\" class=\"button\">"
			."</div></td>"
			."</tr>";
		echo "</table></center></form>";
	closetable();
	tablebreak();
}
/**
* Prints the form for editing the Infusion Settings (access rights)
* @name printCategoryForm
* @param integer [$cid] If editing, which category should be edited
* @param string [$name] If editing, the existing category name is put in the form
* @param string [$action] Either "new" or "edit". Decides the processing of the input data
* @param string [$error] If the input data has errors, the function is recalled with an error message
* @global array $locale Array from language-file (locale-file)
* @author XtraLars <xtralars@baluba.org>
*/
function printCategoryForm($cid, $name, $action, $error) {
	global $locale;
	if ($action == "edit"){
		$header = $locale['REC205'];
		$button = $locale['REC013'];
	} else if ($action == "new"){
		$header = $locale['REC204'];
		$button = $locale['REC011'];
	} else {
		// error
		$header="";
		$button="";
	}
	opentable($header);
		echo "<form action=\"recipe_admin.php\" method=\"post\">";
		echo "<center><table width=\"500\">";
		echo " <tr>"
			."  <td align=\"right\" width=\"35%\">".$locale['REC206'].": </td>"
			."  <td align=\"left\"><input type=\"text\" value=\"".$name."\" name=\"txt_catname\" style=\"width:200px\" class=\"textbox\"></td>"
			."</tr>";
		echo "<tr>"
			." <td colspan=\"2\" align=\"center\">"
			."  <input type=\"hidden\" name=\"formaction\" value=\"".$action."\" />"
			."  <input type=\"hidden\" name=\"cid\" value=\"".$cid."\" />"
			."  <input type=\"submit\" name=\"btn_catadd\" value=\"".$button."\" class=\"button\" />"
			." </td>"
			."</tr>";
		echo "</table></center>";
		echo "</form>";
	closetable();
	tablebreak();
}
// START
$recipe_settings = dbarray(dbquery("SELECT * FROM ".$db_prefix."recipes_settings"));
if(isset($_POST['formaction'])) {
	$action = trim(stripinput($_POST['formaction']));
	switch ($action) {
		case "new":
			// do stuff
			$name = substr(trim(stripinput($_POST['txt_catname'])),0, 100);
			if ($name != "") {
				$sql = "INSERT INTO ".$db_prefix."recipes_categories (cat_name) values ('".$name."')";
				$result = dbquery($sql);
				opentable($locale['REC212']);
				echo "<center>".$locale['REC207']."<em>".$name."</em>".$locale['REC209']."</center>";
				closetable();
				tablebreak();
			} else {
				//### error in name
			}
			break;
		case "edit":
			$name = substr(trim(stripinput($_POST['txt_catname'])),0,100);
			$cid = isNum($_POST['cid']) ? (int) $_POST['cid'] : -1 ;
			if ($cid != -1) {
				$sql = "UPDATE ".$db_prefix."recipes_categories SET cat_name='".$name."' WHERE cat_id=".$cid;
				$result = dbquery($sql);
				opentable($locale['REC211']);
				echo "<center>".$locale['REC207']."<em>".$name."</em>".$locale['REC208']."</center>";
				closetable();
				tablebreak();
			} else {
				//### error in id
			}
		default:
			break;
	}
	printRecipeAdministrationForm();
	printCategoryForm("", "", "new", "");
	printCategoryList();	
} else if (isset($_POST['adminSave'])) {
	$read = isNum($_POST['lst_ReadAccess']) ? (int)$_POST['lst_ReadAccess'] : -1;
	$write = isNum($_POST['lst_WriteAccess']) ? (int)$_POST['lst_WriteAccess'] : -1;
	$moderator = isNum($_POST['lst_Moderator']) ? (int)$_POST['lst_Moderator'] : -1;
	if ($read != -1 && $write != -1 && $moderator != -1) {
		$sql = "UPDATE ".$db_prefix."recipes_settings SET readaccess=".$read.", usergroup=".$write.", moderatorgroup=".$moderator;
		dbquery($sql);
		$recipe_settings = dbarray(dbquery("SELECT * FROM ".$db_prefix."recipes_settings"));
	}
	printRecipeAdministrationForm();
	printCategoryForm("", "", "new", "");
	printCategoryList();	
	
} else if (isset($_GET['action'])) {
	$action = $_GET['action'];
	switch($action) {
		case "edit":
			printRecipeAdministrationForm();
			$catid = isNum($_GET['cid']) ? (int)$_GET['cid'] : -1;
			if ($catid != -1) {
				$sql = "SELECT * FROM ".$db_prefix."recipes_categories WHERE cat_id=".$catid;
				$result = dbquery($sql);
				$rows = dbrows($result);
				
				if ($rows != 0){
					while ($data = dbarray($result) ){
						printCategoryForm($data['cat_id'], $data['cat_name'],"edit","");
					}
				} else {
					//Categoty not found
				}
				printCategoryList();
			} else {
				printRecipeAdministrationForm();
				printCategoryForm("", "", "new", "");
				printCategoryList();	
			}
			break;
		case "delete":
			$catid = (int) trim(stripinput($_GET['cid']));
			
			$sql = "SELECT COUNT(*) AS counter FROM ".$db_prefix."recipes_recipe WHERE cat_id=".$catid;
			$result = dbquery($sql);
			$data = dbarray($result);
			
			if ($data['counter'] == "0"){
				
				$sql = "DELETE FROM ".$db_prefix."recipes_categories WHERE cat_id=".$catid;
				$result = dbquery($sql);
				opentable($locale['REC212']);
				echo "<center>".$locale['REC207'].$locale['REC207']."</center>";
				closetable();
				tablebreak();
	
			} else {
				opentable($locale['REC214']);
				echo "<center>".$locale['REC915']."</center>";
				closetable();
				tablebreak();
			} 	
			printRecipeAdministrationForm();
			printCategoryForm("", "", "new", "");
			printCategoryList();
			break;
		default:
			break;
	}
} else {
	printRecipeAdministrationForm();
	printCategoryForm("", "", "new", "");
	printCategoryList();
}

require_once BASEDIR."footer.php";
?>
