<?php
/**
* Page-description: This php file is the front-end for the normal user. It contains code for browsing, searching, adding, editing and deleting recipes.
* A recipe includes ingredients and a procedure. This page also contains code for managing those.
* It also uses PHP-Fusion comments and rating system. (Comment and Rating character is "R")
* @package infusion
* @tables dbprefix_recipes_categories, dbprefix_recipes_recipe, dbprefix_recipes_settings
*/

/*---------------------------------------------------+
| PHP-Fusion 6 Content Management System 			 |
+----------------------------------------------------+
| Copyright  2002 - 2005 Nick Jones				 |
| http://www.php-fusion.co.uk/ 						 |
+----------------------------------------------------+
| Released under the terms & conditions of v2 of the |
| GNU General Public License. For details refer to   |
| the included gpl.txt file or visit http://gnu.org  |
+----------------------------------------------------+
| Infusion made by XtraLars, Bigwimp, johanf		 |
| ...as a school project and whatnot				 |
+----------------------------------------------------*/
require_once "../../maincore.php";
require_once BASEDIR."subheader.php";
require_once BASEDIR."side_left.php";
require_once INCLUDES."comments_include.php";
require_once INCLUDES."ratings_include.php";

if (file_exists(INFUSIONS."recipe_infusion/locale/".$settings['locale'].".php")) {
	include INFUSIONS."recipe_infusion/locale/".$settings['locale'].".php";
} else {
	include INFUSIONS."recipe_infusion/locale/English.php";
}
// CONSTANTS
define(ERRORCOLOR, "#FF0000", true);

// FUNCTIONS
/**
* Prints a table containing all categories and the amount of recipes registered in each.
* @name printCategoryList
* @tables dbprefix_recipes_categories, dbprefix_recipes_recipe
* @global array $locale Array from language-file (locale-file)
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @author XtraLars <xtralars@baluba.org>
*/
function printCategoryList() {
	global $locale, $db_prefix;
	$sql = "SELECT cat.cat_id, cat.cat_name, COALESCE(count(rec.rec_id),0) as recipes"
		  ." FROM ".$db_prefix."recipes_categories cat LEFT OUTER JOIN ".$db_prefix."recipes_recipe rec ON cat.cat_id = rec.cat_id"
		  ." GROUP BY cat.cat_id, cat.cat_name ORDER BY cat.cat_name";
	$result = dbquery($sql);
	opentable($locale['REC200']);
	if (dbrows($result) != 0) {
		echo "<center><table width=\"500\">";
		echo "<tr>";
		echo "<td><strong>".$locale['REC201']."</strong></td>";
		echo "<td align=\"right\"><strong>".$locale['REC202']."</strong></td>";		
		echo "</tr>";
		while ($data = dbarray($result)) {
			echo "<tr>";
			echo "<td><a href=\"recipes.php?cat_id=".$data['cat_id']."\">".$data['cat_name']."</a></td>";
			echo "<td align=\"right\">".$data['recipes']."</td>";			
			echo "</tr>";
		}
		echo "</table></center>";
	}else {
		echo "<br /><center>".$locale['REC900']."</center><br />";	
	}
	closetable();
	tablebreak();
}
/**
* Prints the contents of a category in a list (table)
* @name printCategoryContents
* @param integer [$cat_id] The Primary Key in the categories-table
* @tables dbprefix_recipes_categories, dbprefix_recipes_recipe
* @global array $locale Array from language-file (locale-file)
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @author XtraLars <xtralars@baluba.org>
*/
function printCategoryContents($cat_id) {
	global $locale, $db_prefix;
	$result = dbquery("SELECT rec.*, cat.cat_name FROM ".$db_prefix."recipes_recipe rec, ".$db_prefix."recipes_categories cat WHERE rec.cat_id=cat.cat_id AND cat.cat_id=".$cat_id);
	$data = dbarray($result);
	opentable($locale['REC100']."<em>".$data['cat_name']."</em>");
	// Checks if there are any returned rows
	if (dbrows($result) != 0) {
		echo "<table width=\"100%\">";
		echo "<tr><td><strong>".$locale['REC101']."</strong></td><td><strong>".$locale['REC102']."</strong></td></tr>";
		echo "<tr>";
		echo "<td><a href=\"recipes.php?action=view&amp;rec_id=".$data['rec_id']."\">".$data['rec_name']."</a></td>";
		echo "<td>".$data['rec_description']."</td>";
		echo "</tr>";
		while ($data = dbarray($result)) {
			echo "<tr>";
			echo "<td><a href=\"recipes.php?action=view&amp;rec_id=".$data['rec_id']."\">".$data['rec_name']."</a></td>";
			echo "<td>".$data['rec_description']."</td>";
			echo "</tr>";
		}
		echo "</table>";
	} else {
		echo "<center>".$locale['REC901']."</center>";
	}
	closetable();
	tablebreak();
}

/**
* Prints a table containing the data registered on a Recipe.
* Then calls functions printRecipeIngredients, printRecipeProcedure and PHP-Fusions included showcomments and showratings
* @name printRecipeDetails
* @param integer [$rec_id] The Primary Key in the dbprefix_recipes_recipe-table
* @tables dbprefix_recipes_categories, dbprefix_recipes_recipe
* @global array $locale Array from language-file (locale-file)
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @author XtraLars <xtralars@baluba.org>
* @see printRecipeIngredients
* @see printRecipeProcedure
*/
function printRecipeDetails($rec_id) {
	global $locale, $db_prefix;
	$write = canEditRecipe($rec_id);

	$sql = "SELECT rec.*, cat.cat_name FROM ".$db_prefix."recipes_categories cat, ".$db_prefix."recipes_recipe rec
	 WHERE cat.cat_id=rec.cat_id AND rec_id=".$rec_id;
	$result = dbquery($sql);
	if(dbrows($result) != 0) {
		$data = dbarray($result);
		$user = dbquery("SELECT * FROM ".$db_prefix."users WHERE user_id=".$data['user_id']);
		if (dbrows($user) != 0) {
			$user = dbarray($user);
			$username = "<a href=\"".BASEDIR."profile.php?lookup=".$user['user_id']."\">".$user['user_name']."</a>";
		} else {
			$username = $locale['REC916'];
		}

		opentable($locale['REC106']);
		echo "<table width=\"100%\">";
		if($data['rec_image'] != "") {
			echo "<tr><td width=\"170\"><center><img src=\"img/uploads/".$data['rec_image']."\" border=\"0\" /></center></td>";
		} else {
			echo "<tr><td width=\"170\" align=\"center\">".$locale['REC902']."</td>";
		}
		echo "<td valign=\"top\"><table width=\"100%\">";
		echo "<tr><td width=\"100px\"><strong>".$locale['REC101']."</strong></td><td>".$data['rec_name']."</td></tr>";
		echo "<tr><td><strong>".$locale['REC102']."</strong></td><td>".stripslashes($data['rec_description'])."</td></tr>";
		echo "<tr><td><strong>".$locale['REC103']."</strong></td><td>".$data['rec_keywords']."</td></tr>";
		echo "<tr><td><strong>".$locale['REC105']."</strong></td><td>".$username."</td></tr>";
		echo "<tr><td><strong>".$locale['REC201']."</strong></td><td>".$data['cat_name']."</td></tr>";
		echo "</table></tr>";
		
		if ($write) {
			echo "<tr><td colspan=\"2\" align=\"right\"><strong>".$locale['REC014']."</strong>: "
				."<a href=\"?action=recEdit&amp;rec_id=".$rec_id."\" >".$locale['REC010']."</a> - "
				."<a href=\"?action=recDelete&amp;rec_id=".$rec_id."\" >".$locale['REC012']."</a></td></tr>";
		}
		echo "</table>";
		closetable();
		tablebreak();
		printRecipeIngredients($rec_id);
		printRecipeProcedure($rec_id);
		showratings("R",$rec_id,"recipes.php?action=view&rec_id=".$rec_id);		
		showcomments("R","recipes_recipe","rec_id",$rec_id,"recipes.php?action=view&rec_id=".$rec_id);
	} else {
		opentable($locale['REC106']);
		echo "<center><br />".$locale['REC903']."<br /><br /></center>";
		closetable();
		tablebreak();
	}
}
/**
* Prints a table containing the ingredients of a given recipe
* Also prints a small form for input of new ingredients
* @name printRecipeIngredients
* @param integer [$cat_id] The Primary Key in the categories-table
* @tables dbprefix_recipes_ingredients
* @global array $locale Array from language-file (locale-file)
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @author XtraLars <xtralars@baluba.org>
* @see canEditRecipe
*/
function printRecipeIngredients($rec_id) {
	global $locale, $db_prefix;
	$write = canEditRecipe($rec_id);
	$cols = $write ? 4 : 3;
	$sql = "SELECT * FROM ".$db_prefix."recipes_ingredients WHERE rec_id=".$rec_id;
	$result = dbquery($sql);
	$rows = dbrows($result);
	opentable($locale['REC300']);
	echo "<table width=\"100%\">";
	echo "<tr><td align=\"center\" width=\"20%\"><strong>".$locale['REC301']."</strong></td><td><strong>".$locale['REC302']."</strong></td>";
	if ($write) { 
		echo "<td align=\"right\" width=\"10%\"><strong>".$locale['REC014']."</strong></td>";
	}
	echo "</tr>";
	if($rows != 0) {
		while ($data = dbarray($result)) {
			echo "<tr><td style=\"overflow:hidden\"><center>".$data['ing_amount']."</center></td><td style=\"overflow:hidden\">".$data['ing_type']."</td>";
			if ($write) {
				echo "<td align=\"right\">"
					."<a href=\"recipes.php?action=delIng&amp;ing_id=".$data['ing_id']."&amp;rec_id=".$rec_id."\">".$locale['REC012']."</a>"
					."</td>";
			}
			echo "</tr>";
		}
	} else {
		echo "<tr><td align=\"center\" colspan=\"".$cols."\">".$locale['REC904']."</td></tr>";
	}
	if($write) {
		echo "<tr><td colspan=\"".$cols."\">\n<form action=\"recipes.php?action=addIng&amp;rec_id=".$rec_id."\" method=\"post\">"
			."<table width=\"100%\" cellspacing=\"0\" cellpadding=\"0\">";
		echo "\n<tr><td width=\"20%\" align=\"center\">"
			."<input name=\"txt_amount\" type=\"text\" class=\"textbox\" style=\"width:90%\" /></td>"
			."\n<td><input name=\"txt_type\" type=\"text\" class=\"textbox\" style=\"width:90%\" /></td>"
			."\n<td align=\"right\" width=\"10%\"><input type=\"submit\" name=\"btn_add\" value=\"".$locale['REC011']."\" class=\"button\"/></td>"
			."</tr></form></table>\n</tr>";
	}
	echo "</table>";	
	closetable();
	tablebreak();
}

/**
* Prints a list/menu containing Step types (wait, boil, prepare, fry etc)
* It gets its contents from the locale-file (both value and label)
* @name printProcedyreTypeList
* @param string [$selected] The value of the selected type (for showing with existing value)
* @global array $locale Array from language-file (locale-file)
* @author XtraLars <xtralars@baluba.org>
*/
function printProcedyreTypeList($selected) {
	global $locale;
	$types = $locale['REC350'];
	echo "<select name=\"lstStepTypes\" class=\"textbox\" style=\"width:80px\">";
	foreach ($types as $value => $label) {
		if ($value == $selected) {
			echo "<option value=\"".$value."\" selected=\"selected\">".$label."</option>";
		} else {
			echo "<option value=\"".$value."\">".$label."</option>";
		}
	}
	echo "</select>";
}
/**
* Prints a table containing the steps of a given recipe
* Also prints a small form for input of new steps, and links for editing or deleting steps. Form also handles editing
* @name printRecipeProcedure
* @param integer [$rec_id] The Primary Key in the dbprefix_recipes_recipe-table
* @tables dbprefix_recipes_procedure
* @global array $locale Array from language-file (locale-file)
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @author XtraLars <xtralars@baluba.org>
* @see canEditRecipe
*/
function printRecipeProcedure($rec_id) {
	global $locale, $db_prefix;
	$write = canEditRecipe($rec_id);
	$cols = $write ? 4 : 3;

	$sql = "SELECT * FROM ".$db_prefix."recipes_procedure WHERE rec_id=".$rec_id." ORDER BY pro_order ASC";
	$result = dbquery($sql);
	$rows = dbrows($result);
	opentable($locale['REC351']);
	echo "<table width=\"100%\">";
	echo "<tr>"
		."  <td width=\"10%\" align=\"center\"><strong>".$locale['REC352']."</strong></td>\n"
		."  <td width=\"15%\"><center><strong>".$locale['REC353']."</strong></center></td>\n"
		."  <td><strong>".$locale['REC354']."</strong></td>\n";
	if ($owner) { echo "<td align=\"right\" width=\"20%\"><strong>".$locale['REC014']."</strong></td>"; }
	echo "</tr>";
	$currentrow = 0;
	if($rows != 0) {
		while ($data = dbarray($result)) {
			echo "<tr><td align=\"center\" style=\"overflow:hidden\">".$data['pro_order']."</td>"
				."<td align=\"center\" style=\"overflow:hidden\">"
				."<img src=\"img/".$data['pro_type'].".gif\" heigth=\"20\" width=\"20\" /></td>"
				."<td style=\"overflow:hidden\">".$data['pro_text']."</td>";
			if ($write) {
				echo "<td align=\"right\">";
				$printed = false;
				if ($currentrow != 0) {
					echo "<a href=\"recipes.php?action=stepUp&amp;rec_id=".$rec_id."&amp;step=".$data['pro_id']."\" >";
					echo "  <img src='".THEME."images/up.gif' alt='".$locale['REC015']."' title='".$locale['REC015']."' style='border:0px;'>";
					echo "</a>";
					$printed = true;
				} 
				if ($currentrow != $rows-1) {
					echo "<a href=\"recipes.php?action=stepDown&amp;rec_id=".$rec_id."&amp;step=".$data['pro_id']."\" >";
					echo "  <img src='".THEME."images/down.gif' alt='".$locale['REC016']."' title='".$locale['REC016']."' style='border:0px;'>";
					echo "</a>";
					$printed = true;
				} else {
					echo " <img src='".THEME."images/blank.gif' width=\"13\" heigth=\"10\" alt='".$locale['REC017']."' title='".$locale['REC017']."' style='border:0px;'>";
				}
				if ($printed) { echo " - "; }
				echo "<a href=\"recipes.php?action=stepEdit&amp;rec_id=".$rec_id."&amp;step=".$data['pro_id']."\" >".$locale['REC010']."</a> - ";
				echo "<a href=\"recipes.php?action=stepDelete&amp;rec_id=".$rec_id."&amp;step=".$data['pro_id']."\" >".$locale['REC012']."</a>";
				echo "</td>";
			}
			echo "</tr>";
			$currentrow++;
		}
	} else {
		echo "<tr><td align=\"center\" colspan=\"".$cols."\">".$locale['REC905']."</td></tr>";
	}
	if($write) {
		if (isset($_GET['action']) && $_GET['action'] == "stepEdit") {
			$step_id = isNum($_GET['step']) ? (int) $_GET['step'] : -1;
			$sql = "SELECT * FROM ".$db_prefix."recipes_procedure WHERE pro_id=".$step_id;
			$step = dbarray(dbquery($sql));
			$step_id = $step['pro_id'];
			$step_type = $step['pro_type'];
			$step_text = $step['pro_text'];
			$action = "stepEdited";
			$button = $locale['REC013'];
		} else {
			$step_id = "";
			$step_type = "";
			$step_text = "";
			$action = "addStep";
			$button = $locale['REC011'];
		}
		echo "<tr>"
			."  <td colspan=\"".$cols."	\">\n<form action=\"recipes.php?action=".$action."&amp;rec_id=".$rec_id."\" method=\"post\">"
			."<table width=\"100%\" cellspacing=\"0\" cellpadding=\"0\">\n<tr>"
			."  <td width=\"10%\">&nbsp;</td>"
			."  <td width=\"15%\" align=\"center\">";
			printProcedyreTypeList($step_type);
		echo "</td>\n"
			."<td><input name=\"txt_action\" value=\"".$step_text."\" type=\"text\" class=\"textbox\" style=\"width:90%\" /></td>"
			."<td align=\"right\" width=\"20%\"><input type=\"hidden\" name=\"hidStepId\" value=\"".$step_id."\" />"
			."<input type=\"submit\" name=\"btn_save\" value=\"".$button."\" class=\"button\"/></td>"
			."</tr></form></table>\n</tr>";
	} 
	
	echo "</table>";	
	closetable();
	tablebreak();
}
/**
* Prints the form for searching
* @name printRecipeSearchForm
* @param string [$string] Search-string
* @param string [$cat] Where to search (i = ingredients, d = description, k = keywords)
* @param string [$error] What error to show. Normally = "".
* @global array $locale Array from language-file (locale-file)
* @author XtraLars <xtralars@baluba.org>
*/
function printRecipeSearchForm($string, $cat, $error) {
	global $locale;
	opentable($locale['REC040']);
	echo "<center><form name=\"rec_search\" method=\"post\" action=\"recipes.php\">";
	echo $locale['REC041']." <input type=\"text\" name=\"txt_RecipeSearch\" value=\"".$string."\" class=\"textbox\" style=\"width: 200px;\">\n";
	echo "<input type=\"submit\" name=\"btn_rec-search\" value=\"".$locale['REC042']."\" class=\"button\"><br />\n";
	if ($cat=="i") { 
		echo "<input name=\"searchWhat\" type=\"radio\" value=\"i\" checked />".$locale['REC303']."\n";
	}else { 
		echo "<input name=\"searchWhat\" type=\"radio\" value=\"i\" />".$locale['REC303']."\n";
	}
	if ($cat=="d") { 
		echo "<input name=\"searchWhat\" type=\"radio\" value=\"d\" checked />".$locale['REC102']."\n";
	}else { 
		echo "<input name=\"searchWhat\" type=\"radio\" value=\"d\" />".$locale['REC102']."\n";
	}
	if ($cat=="k") { 
		echo "<input name=\"searchWhat\" type=\"radio\" value=\"k\" checked />".$locale['REC103']."\n";
	}else { 
		echo "<input name=\"searchWhat\" type=\"radio\" value=\"k\" />".$locale['REC103']."\n";
	}
	echo "<br /><strong><span style=\"color:red\">".$error."</span></strong></form></center>\n";
	closetable();
	tablebreak();
}
/**
* Prints a list/menu containing all recipe categories.
* Also prints a small form for input of new steps, and links for editing or deleting steps. Form also handles editing
* @name printCategoryDropList
* @param integer [$cat_id] The Primary Key in the dbprefix_recipes_categories table. Used to point out what should be selected in the menu
* @tables dbprefix_recipes_categories
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @author XtraLars <xtralars@baluba.org>
*/
function printCategoryDropList($cat_id) {
	global $db_prefix;
	$sql = "SELECT * FROM ".$db_prefix."recipes_categories";
	$result = dbquery($sql);
	$rows = dbrows($result);
	echo "<select name=\"lst_categories\" style=\"width:220px;\" class=\"textbox\">";
	if($rows != 0) {
		while($data = dbarray($result)) {
			if($data['cat_id'] == $cat_id) {
				echo "<option value=\"".$data['cat_id']."\" selected=\"selected\" >".$data['cat_name']."</option>";
			} else {
				echo "<option value=\"".$data['cat_id']."\">".$data['cat_name']."</option>";
			}
		}
	}
	echo "</select>";
}
/**
* Prints the form for adding or editing Recipes.
* Also prints a small form for input of new steps, and links for editing or deleting steps. Form also handles editing
* @name printRecipeForm
* @param integer [$rec_id] If editing, the ID is sent to the function to be added in the form
* @param string [$rec_name] If editing, the name is sent to the function to be added in the form
* @param string [$rec_keyword] If editing, the keywords are sent to the function to be added in the form
* @param integer [$cat_id] If editing, the category ID is sent to the function to be added in the form
* @param string [$rec_desc] If editing, the description is sent to the function to be added in the form
* @param string [$rec_imgLoc] If editing, the image location is sent to the function to be added in the form
* @param string [$action] Either "new" or "edit". It decides the processing of the form data
* @param string [$error] If the input data has errors, the function is recalled with an error message
* @tables dbprefix_recipes_categories
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @global array $locale Array from language-file (locale-file)
* @author XtraLars <xtralars@baluba.org>
*/
function printRecipeForm($rec_id, $rec_name, $rec_keyword, $cat_id, $rec_desc, $rec_imgLoc, $action, $error) {
	global $locale, $db_prefix;
	if ($action == "new") {
		$button = $locale['REC018'];
	} else {
		$button = $locale['REC013'];
	}
	$cats = dbrows(dbquery("SELECT * FROM ".$db_prefix."recipes_categories"));
	if ($cats > 0) {
		opentable($locale['REC107']);
			echo "<form action=\"recipes.php\" method=\"post\" enctype=\"multipart/form-data\" name=\"recipeform\">";
			echo "<center><table width=\"500\">";
			echo "<tr><td>".$locale['REC101'].":</td><td><input name=\"txt_name\" type=\"text\" value=\"".$rec_name."\" class=\"textbox\" style=\"width:220px;\" /></td></tr>";
			echo "<tr><td>".$locale['REC103'].":</td><td><input name=\"txt_keywords\" type=\"text\" value=\"".$rec_keyword."\" class=\"textbox\" style=\"width:220px;\" /></td></tr>";
			echo "<tr><td>".$locale['REC203'].":</td><td>";
				printCategoryDropList($cat_id);
			echo "</td></tr>";
			echo "<tr><td valign=\"top\">".$locale['REC102'].":</td>"
				."<td><textarea name=\"txt_description\" class=\"textbox\" style=\"width:220px;\" rows=\"7\">".$rec_desc."</textarea></td></tr>";
			echo "<tr><td valign=\"top\">".$locale['REC108'].":</td><td>";
			if ($rec_imgLoc != "") {
				echo "<img src=\"img/uploads/".$rec_imgLoc."\" /><br /><br />";
			}
			echo "<input name=\"fil_recipeimage\" type=\"file\" class=\"textbox\" style=\"width:220px;\" /></td></tr>";
			echo "<tr><td>&nbsp;</td><td>".$locale['REC109']."</td></tr>";
			if ($error != "") {
				echo "<tr><td>&nbsp;</td><td style=\"color:".ERRORCOLOR."\">".$error."</td></tr>";
			}
			echo "<tr><td colspan=\"2\" align=\"right\"><input name=\"hid_recid\" type=\"hidden\" value=\"".$rec_id."\">"
				."<input name=\"hid_action\" type=\"hidden\" value=\"".$action."\">"
				."<input name=\"btn_submit\" type=\"submit\" class=\"button\" value=\"".$button."\"></td></tr>";
			echo "</table></center>";
			echo "</form>";
		closetable();
		tablebreak();
	}
}
/**
* Checks the file size, height and width of a given image.
* @name checkImage
* @param string [$imagefile] Where the image is located on the server ($_FILES[...]['tmp_name'])
* @param integer [$imagesize] Image size ($_FILES[...]['size'])
* @global array $recipe_settings Array containing the Infusion Settings.
* @global array $locale Array from language-file (locale-file)
* @return boolean Returns weither the image is usable or not.
* @author XtraLars <xtralars@baluba.org>
*/
function checkImage($imagefile, $imagesize) {
	global $recipe_settings, $locale;
	$maxSize = 42000;
	$maxWidth = 130;
	$maxHeight = 130;
	$return = "";
	$imagesize = (int) $imagesize;
	if ($imagesize > $maxSize) {
		$return .= $locale['REC907']." ".$locale['REC405'].": ".$imagesize." ".$locale['REC404'].", ".$locale['REC402'].": ".$maxSize." ".$locale['REC404']."<br />";
	} 
	list($width, $height, $type, $attr) = getimagesize($imagefile);
	//echo " type: ".$type." width: ".$width." height ".$height." attr ".$attr;
	switch (exif_imagetype($imagefile)) {
		case IMAGETYPE_GIF:
			break;
		case IMAGETYPE_JPEG:
			break;
		case IMAGETYPE_PNG:
			break;
		default:
			$return .= $locale['REC908']."<br />";		
	}
	if ($width > $maxWidth) { 
		$return .= $locale['REC909']." ".$locale['REC400'].": ".$width.", ".$locale['REC402'].": ".$maxWidth."<br />";
	}
	if ($height > $maxHeight) {
		$return .= $locale['REC910']." ".$locale['REC401'].": ".$height.", ".$locale['REC402'].": ".$maxHeight."<br />";
	}

	if ($return == "") {
		return true;
	} else {
		return $return;
	}
}
/**
* Moves the uploaded image from "tmp" to img/uploads/ folder and renames it.
* @name saveRecipeImage
* @param string [$imagefile] Where the image is located on the server ($_FILES[...]['tmp_name'])
* @param string [$imagename] Original Image Name ($_FILES[...]['name'])
* @param integer [$rec_id] The recipe the image should be used with.
* @return boolean If the move is unsuccessful, it returns false
* @return string If the move is successful, it returns the file name ([rec_id]imagename.ext)
* @author XtraLars <xtralars@baluba.org>
*/
function saveRecipeImage($imagefile, $imagename, $rec_id) {
	$folder = "img/uploads/";
	$newname = "[".$rec_id."]".$imagename;
	if (move_uploaded_file($imagefile, $folder.$newname)) {
		return $newname;
	} else {
		return false;
	}
}
/**
* Deletes a file. Used to delete the image when a recipe is deleted or gets a new image.
* @name deleteRecipeImage
* @param string [$imagefile] Where the image is located on the server
* @param integer [$rec_id] The recipe the image should be used with.
* @author XtraLars <xtralars@baluba.org>
*/
function deleteRecipeImage($imagefile) {
	$folder = "img/uploads/";
	unlink($folder.$imagefile);
}
/**
* Checks to see if the active user has access to editing a certain recipe. This could be that the user is the "owner" of the recipe 
* and is still in the usergroup (those with write access), or it can be a member of the moderator-group. {@source}
* @name canEditRecipe
* @param integer [$rec_id] The recipe the image should be used with.
* @global string $db_prefix String representing the PHP-Fusion table prefix (ie: "fusion_")
* @global array $userdata A PHP-Fusion array containing data about the current user.
* @global array $recipe_settings Array containing the infusion settings.
* @return boolean If the user should be able to edit / delete the recipe, it returns true
* @author XtraLars <xtralars@baluba.org>
*/
function canEditRecipe($rec_id) {
	global $db_prefix, $userdata, $recipe_settings;
	$return = false;
	$owner = dbarray(dbquery("SELECT user_id FROM ".$db_prefix."recipes_recipe where rec_id=".$rec_id));
	if ($owner['user_id'] == $userdata['user_id'] && checkGroup($recipe_settings['usergroup'])) {
		$return = true;
	} else if (checkGroup($recipe_settings['moderatorgroup'])){
		$return = true;
	}
	return $return;
}	
	
// START RECEIVING DATA
$recipe_settings = dbarray(dbquery("SELECT * FROM ".$db_prefix."recipes_settings"));
$recipe_name_maxLength = 80;
$recipe_keywords_maxLength = 255;
$recipe_ingType_maxLength = 70;
$recipe_ingAmount_maxLength = 25;
$recipe_stepType_maxLength = 20;

if (checkgroup($recipe_settings['readaccess'])) {
	if (isset($_POST['txt_RecipeSearch'])) {
		$searchString = trim(stripinput($_POST['txt_RecipeSearch']));
		$searchCat = trim(stripinput($_POST['searchWhat']));
		$do_search = true;
		if ($searchString=="") {
			printRecipeSearchForm($searchString, $searchCat, $locale['REC041']);
			$do_search = false;
		} else {
			printRecipeSearchForm($searchString, $searchCat, "");
		}
		if ($do_search) {
			switch($searchCat) {
				case "i":
					$sql = "SELECT cat.cat_name, rec.rec_id, rec.rec_name, rec.rec_keywords, SUBSTRING(rec.rec_description,1,55) as descr" 
						." FROM ".$db_prefix."recipes_recipe rec, ".$db_prefix."recipes_ingredients ing, ".$db_prefix."recipes_categories cat"
						." WHERE cat.cat_id=rec.cat_id AND ing.rec_id=rec.rec_id AND ing.ing_type like '%".$searchString."%'";
					break;
				case "k":
					$sql = "SELECT cat.cat_name, rec.rec_id, rec.rec_name, rec.rec_keywords, SUBSTRING(rec.rec_description,1,55) as descr"
						." FROM ".$db_prefix."recipes_recipe rec, ".$db_prefix."recipes_categories cat"
						." WHERE cat.cat_id=rec.cat_id AND rec.rec_keywords LIKE '%".$searchString."%'";
					break;
				case "d":
					$sql = "SELECT cat.cat_name, rec.rec_id, rec.rec_name, rec.rec_keywords, SUBSTRING(rec.rec_description,1,55) as descr"
						." FROM ".$db_prefix."recipes_recipe rec, ".$db_prefix."recipes_categories cat"
						." WHERE cat.cat_id=rec.cat_id AND rec.rec_description LIKE '%".$searchString."%'";
					break;
				default:
					$nothing = "";
			}
			$result = dbquery($sql);
			$rows = dbrows($result);
			opentable($locale['REC044']);
				if ($rows != 0) {
					while($data = dbarray($result)) {
						echo "<a href=\"recipes.php?action=view&amp;rec_id=".$data['rec_id']."\">".$data['rec_name']."</a><br />";
						if($searchCat=="k") {
							$keywords = preg_replace("/".$searchString."/", "<strong>".$searchString."</strong>", $data['rec_keywords']);
							echo "<em>".$locale['REC103']."</em>: ".$keywords." - <em>".$locale['REC102']."</em>: ".$data['descr'];
						} else if ($searchCat=="d") {
							$description = preg_replace("/".$searchString."/", "<strong>".$searchString."</strong>", $data['descr']);
							echo "<em>".$locale['REC103']."</em>: ".$data['rec_keywords']." - <em>".$locale['REC102']."</em>: ".$description;
						} else {
							echo "<em>".$locale['REC103']."</em>: ".$data['rec_keywords']." - <em>".$locale['REC102']."</em>: ".$data['descr'];
						}
						echo "<br /><em>".$locale['REC203']."</em>: ".$data['cat_name']."<br /><br />";
					}
					echo "<center><br />".$locale['REC045'].$rows.$locale['REC110']."<br /><br /></center>";
				} else {
					echo "<center><br />".$locale['REC045']."0".$locale['REC110']."<br /><br /></center>";
				}
			closetable();
			tablebreak();
		}
	} else if(isset($_GET['cat_id'])) {
		// Print all recipes in the category
		$cat_id = isNum($_GET['cat_id']) ? (int) $_GET['cat_id'] : -1;
		printCategoryContents($cat_id);
	} else if(isset($_GET['action'])) {
		$action = trim(stripinput($_GET['action']));
		$rec_id = isNum($_GET['rec_id']) ? (int) $_GET['rec_id'] : -1;
		$write = canEditRecipe($rec_id);
		switch ($action) {
			case "view":
				printRecipeDetails($rec_id);
				break;
			case "addIng":
				if ($write) {
					$amount = substr(trim(stripinput($_POST['txt_amount'])),0, $recipe_ingAmount_maxLength);
					$type = substr(trim(stripinput($_POST['txt_type'])),0,$recipe_ingType_maxLength);
					if ($amount == "" || $type == "") {
						// nada
					} else {
						$sql = "INSERT INTO ".$db_prefix."recipes_ingredients (rec_id, ing_amount, ing_type) "
							  ."values (".$rec_id.", '".$amount."', '".$type."')";
						$result = dbquery($sql);
					}
					printRecipeDetails($rec_id);
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "recEdit":
				if ($write) {
					$recipe = dbarray(dbquery("SELECT * FROM ".$db_prefix."recipes_recipe WHERE rec_id=".$rec_id));
					printRecipeForm($recipe['rec_id'], $recipe['rec_name'], $recipe['rec_keywords'], $recipe['cat_id'], $recipe['rec_description'], $recipe['rec_image'], "edit", "");
					printRecipeIngredients($rec_id);
					printRecipeProcedure($rec_id);
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "delIng":
				if ($write) {
					$ing = isNum($_GET['ing_id']) ? (int) $_GET['ing_id'] : -1;
					if ($ing != -1) {
						dbquery("DELETE FROM ".$db_prefix."recipes_ingredients WHERE rec_id=".$rec_id." AND ing_id=".$ing);
					}
					printRecipeDetails($rec_id);
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "addStep":
				// check ownership
				if ($write) {
					$type = substr(trim(stripinput($_POST['lstStepTypes'])),0,$recipe_stepType_maxLength);
					$action = trim(stripinput($_POST['txt_action']));
					$neworder = dbarray(dbquery("select COALESCE(max(pro_order),0) as new from ".$db_prefix."recipes_procedure where rec_id=".$rec_id));
					$neworder = (int) $neworder['new'];
					$neworder++;
					$sql = "INSERT INTO ".$db_prefix."recipes_procedure (rec_id, pro_type, pro_order, pro_text) VALUES (".$rec_id.", '".$type."', ".$neworder.", '".$action."')";
					dbquery($sql);
					printRecipeDetails($rec_id);
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "stepEdit":
				printRecipeDetails($rec_id);
				break;
			case "stepEdited":
				// check ownership
				if ($write) {
					$step_id = isNum($_POST['hidStepId']) ? (int) $_POST['hidStepId'] : -1;
					$step_type = substr(trim(stripinput($_POST['lstStepTypes'])), 0, $recipe_stepType_maxLength);
					$step_text = trim(stripinput($_POST['txt_action']));
					if ($step_id != -1) {
						dbquery("UPDATE ".$db_prefix."recipes_procedure SET pro_type='".$step_type."', pro_text='".$step_text."' WHERE pro_id=".$step_id);
					}
					printRecipeDetails($rec_id);
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "stepDelete":
				// check ownership
				if ($write) {
					$stepid = isNum($_GET['step']) ? (int) $_GET['step'] : -1;
					$step = dbarray(dbquery("SELECT * FROM ".$db_prefix."recipes_procedure WHERE rec_id=".$rec_id." AND pro_id=".$stepid));
					$order = (int) $step['pro_order'];
					$delSql = "DELETE FROM ".$db_prefix."recipes_procedure WHERE pro_id=".$stepid;
					$updateSql = "UPDATE ".$db_prefix."recipes_procedure SET pro_order=pro_order-1 WHERE rec_id=".$rec_id." AND pro_order>".$order;
					dbquery($delSql);
					dbquery($updateSql);
					printRecipeDetails($rec_id);
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "stepUp":
				// check ownership
				if ($write) {
					$stepid = isNum($_GET['step']) ? (int) $_GET['step'] : -1;
					$step = dbarray(dbquery("SELECT * FROM ".$db_prefix."recipes_procedure WHERE pro_id=".$stepid));
					$swapfrom = (int) $step['pro_order'];
					if ($swapfrom != 0) {
						$swapto = $swapfrom -1;
						$other = dbarray(dbquery("SELECT pro_id, pro_order FROM ".$db_prefix."recipes_procedure WHERE rec_id=".$rec_id." AND pro_order<".$swapfrom." ORDER BY pro_order DESC LIMIT 0,1"));
						$result = dbquery("UPDATE ".$db_prefix."recipes_procedure SET pro_order=pro_order+1 WHERE rec_id=".$rec_id." AND pro_id=".$other['pro_id']);
						$result = dbquery("UPDATE ".$db_prefix."recipes_procedure SET pro_order=pro_order-1 WHERE rec_id=".$rec_id." AND pro_id=".$step['pro_id']);
					}
					printRecipeDetails($rec_id);
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "stepDown":
				// check ownership
				if ($write) {
					$stepid = isNum($_GET['step']) ? (int) $_GET['step'] : -1;
					$step = dbarray(dbquery("SELECT * FROM ".$db_prefix."recipes_procedure WHERE pro_id=".$stepid));
					$swapfrom = (int) $step['pro_order'];
					$swapto = $swapfrom +1;
					$other = dbarray(dbquery("SELECT pro_id, pro_order FROM ".$db_prefix."recipes_procedure WHERE rec_id=".$rec_id." AND pro_order>".$swapfrom." ORDER BY pro_order ASC LIMIT 0,1"));
					$result = dbquery("UPDATE ".$db_prefix."recipes_procedure SET pro_order=pro_order-1 WHERE rec_id=".$rec_id." AND pro_id=".$other['pro_id']);
					$result = dbquery("UPDATE ".$db_prefix."recipes_procedure SET pro_order=pro_order+1 WHERE rec_id=".$rec_id." AND pro_id=".$step['pro_id']);
					printRecipeDetails($rec_id);
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "recDelete":
				// check ownership
				if ($write) {
					$image = dbarray(dbquery("SELECT rec_image FROM ".$db_prefix."recipes_recipe WHERE rec_id=".$rec_id));
					deleteRecipeImage($image['rec_image']);
					dbquery("DELETE FROM ".$db_prefix."recipes_procedure WHERE rec_id=".$rec_id);
					dbquery("DELETE FROM ".$db_prefix."recipes_ingredients WHERE rec_id=".$rec_id);
					dbquery("DELETE FROM ".$db_prefix."recipes_recipe WHERE rec_id=".$rec_id);
					dbquery("DELETE FROM ".$db_prefix."comments WHERE comment_item_id='$rec_id' and comment_type='R'");
					dbquery("DELETE FROM ".$db_prefix."ratings WHERE rating_item_id='$rec_id' and rating_type='R'");
					
					opentable($locale['REC113']);
						echo "<center><table width=\"500\"><tr><td align=\"center\">".$locale['REC114']."</td></tr></table></center>";
					closetable();
					tablebreak();
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			default:
				fallback("recipes.php");
				break;
		}
	} else if (isset($_POST['hid_action'])) {
		$action = trim(stripinput($_POST['hid_action']));
		switch ($action) {
			case "new":
				if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {
					$cats = dbrows(dbquery("SELECT * FROM ".$db_prefix."recipes_categories"));
					if ($cats > 0) {
						$error = "";
						$name = trim(stripinput($_POST['txt_name']));
						if ($name == "") {
							$error .= $locale['REC912']."<br />";
						}
						$keywords = trim(stripinput($_POST['txt_keywords']));
						$catid = isNum($_POST['lst_categories']) ? (int) $_POST['lst_categories'] : -1;
						$exists = dbarray(dbquery("SELECT COUNT(cat_id) as CATS FROM ".$db_prefix."recipes_categories WHERE cat_id=".$catid));
						if ($exists['CATS'] == "0") { 
							$error .= $locale['REC913']."<br />";
						}
						$description = trim(stripinput($_POST['txt_description']));
						$imagefile = $_FILES['fil_recipeimage']['tmp_name'];
						$imagefilesize = $_FILES['fil_recipeimage']['size'];
						$imagename = $_FILES['fil_recipeimage']['name'];
						if ($imagefile != "") {
							$imageok = checkImage($imagefile, $imagefilesize);
						} else {
							$imageok = true;
						}
						if (is_bool($imageok) && $imageok == true && $catid != -1 && $error == "") {
							$rec_id = dbarray(dbquery("SELECT MAX(rec_id) as id FROM ".$db_prefix."recipes_recipe"));
							$rec_id = (int) $rec_id['id'];
							$rec_id++;
							if ($imagefile != "") {
								$image = saveRecipeImage($imagefile, $imagename, $rec_id);
							} else {
								$image = "";
							}
							$sql = "INSERT INTO ".$db_prefix."recipes_recipe (rec_id, cat_id, rec_keywords, rec_description, user_id, rec_name, rec_image) "
								  ."values (".$rec_id.", ".$catid.", '".$keywords."', '".$description."',  ".$userdata['user_id'].",  '".$name."', '".$image."')";
							$result = dbquery($sql);
							$data = dbarray(dbquery("SELECT max(rec_id) as id FROM ".$db_prefix."recipes_recipe WHERE user_id=".$userdata['user_id']." AND rec_name='".$name."'"));
							$rec_id = $data['id'];
							opentable($locale['REC112']);
								echo "<center>".$locale['REC111']."</center>";
							closetable();
							tablebreak();
							printRecipeDetails($rec_id);
						} else {
							$error .= $imageok;
							printRecipeForm("", $name, $keywords, $catid, $description, "", "new", $error);
						}
					}
				} else {
					printRecipeSearchForm("", "i", "");
					printCategoryList();
					if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
						printRecipeForm("", "", "", "", "", "", "new", "");
					}
				}
				break;
			case "edit":
				$rec_id = isNum($_POST['hid_recid']) ? (int) $_POST['hid_recid'] : -1;
				if ($rec_id != -1) {
					$write = canEditRecipe($rec_id);
					if ($write) {
						$recipe = dbarray(dbquery("SELECT * FROM ".$db_prefix."recipes_recipe WHERE rec_id=".$rec_id));
						$error = "";
						$name = substr(trim(stripinput($_POST['txt_name'])),0, $recipe_name_maxLength);
						if ($name == "") {
							$error .= $locale['REC912']."<br />";
						}
						$keywords = substr(trim(stripinput($_POST['txt_keywords'])), 0, $recipe_keywords_maxLength);
						$catid = isNum($_POST['lst_categories']) ? (int) $_POST['lst_categories'] : -1;
						$exists = dbarray(dbquery("SELECT COUNT(cat_id) as CATS FROM ".$db_prefix."recipes_categories WHERE cat_id=".$catid));
						if ($exists['CATS'] == "0") { 
							$error .= $locale['REC913']."<br />";
						}
						$description = trim(stripinput($_POST['txt_description']));
						$imagefile = $_FILES['fil_recipeimage']['tmp_name'];
						$imagefilesize = $_FILES['fil_recipeimage']['size'];
						$imagename = $_FILES['fil_recipeimage']['name'];
						if ($imagefile != "") {
							$imageok = checkImage($imagefile, $imagefilesize);
						} else {
							$imageok = true;
						}
						if (is_bool($imageok) && $imageok == true && $error == "") {
							if ($imagefile != "") {
								$image = saveRecipeImage($imagefile, $imagename, $rec_id);
								deleteRecipeImage($recipe['rec_image']);
							} else {
								$image = $recipe['rec_image'];
							}
							if ($error == "") {
								if ($catid != -1 && $rec_id != -1 && $name != "") {
									$sql = "UPDATE ".$db_prefix."recipes_recipe"
										  ." SET cat_id=".$catid.", rec_keywords='".$keywords."', rec_description='".$description."', rec_name='".$name."', rec_image='".$image."' WHERE rec_id=".$rec_id."";
									$result = dbquery($sql);
									printRecipeDetails($rec_id);
								} else {
									fallback("recipes.php");
								}
							} else {
								printRecipeForm($rec_id, $name, $keywords, $catid, $description, $image, "edit", $error);
							}
						}
					} else {
						printRecipeSearchForm("", "i", "");
						printCategoryList();
						if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
							printRecipeForm("", "", "", "", "", "", "new", "");
						}
					}
				} else {
					fallback("recipes.php");
				}
				break;
			default:
				fallback("recipes.php");
				break;
		}
	} else { 
		printRecipeSearchForm("", "i", "");
		printCategoryList();
		if (checkgroup($recipe_settings['usergroup']) || checkgroup($recipe_settings['moderatorgroup'])) {		
			printRecipeForm("", "", "", "", "", "", "new", "");
		}
	}
}
require_once BASEDIR."side_right.php";
require_once BASEDIR."footer.php";
?>